/********************************************************************
 File: bootloader.c

 Description:
 This file contains functions to handle bootloader interaction.

 Authors and Copyright:
 (c) 2018, Thomas Fischl (http://www.fischl.de/contact.html)

 Device: PIC16LF1455
 Compiler: Microchip MPLAB XC8 C Compiler V1.44

 License:
 This file is part of the USBtin firmware project and is copyrighted by the
 authors listed above. It is free for private or educational non-commercial use
 (for a commercial license please contact the authors). It may not be
 redistributed without the prior written consent of the authors.
 
 It is provided "as is" without warranty of any kind, either express or implied,
 including without limitation any implied warranties of condition, uninterrupted
 use, merchantability, fitness for a particular purpose, or non-infringement. In
 no event shall the authors be liable for any direct or indirect damages arising
 in any way out of the use of it.
 
 ********************************************************************/

#include "clock.h"
#include "usb.h"
#include "bootloader.h"

#define BOOTLOADER_STATE_OFF 0
#define BOOTLOADER_STATE_TRIGGERED 1
#define BOOTLOADER_STATE_SHUTDOWNAPP 2

unsigned char bootloader_state = BOOTLOADER_STATE_OFF;
unsigned char bootloader_timestamp;

void bootloader_triggerStart() {
    bootloader_state = BOOTLOADER_STATE_TRIGGERED;
    bootloader_timestamp = clock_tickerSlow;
    
}

void bootloader_process() {
    
    switch (bootloader_state) {
        
        case BOOTLOADER_STATE_OFF:
            return;
            
        case BOOTLOADER_STATE_TRIGGERED:
            if (clock_diff(bootloader_timestamp) > 25) {
                bootloader_state = BOOTLOADER_STATE_SHUTDOWNAPP;
                bootloader_timestamp = clock_tickerSlow;
                
                usb_shutdown();
            }
            break;
            
        case BOOTLOADER_STATE_SHUTDOWNAPP:
            if (clock_diff(bootloader_timestamp) > 25) {
                
                // jump to bootloader
                asm ("MOVLP 0x00");
                asm ("GOTO 0x30");                
            }
            break;
    }        
    
}
